==> question2answer-1.5-language-pt-BR.zip: pt/qa-lang-question.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-question.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for question page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer_title' => '1 Resposta',
		'a_convert_to_c_on' => 'Converter esta resposta em comentário em:',
		'a_convert_to_c' => 'Converter esta resposta em um comentário',
		'a_convert_warn_cs' => 'Aviso: Esta conversão não pode ser revertida e também moverá os comentários dessa resposta.',
		'a_convert_warn' => 'Aviso: Esta conversão não pode ser revertida.',
		'a_notify_email' => 'Envia-me um email nesse endereço se minha resposta for escolhida ou comentada:',
		'a_notify_label' => 'Envia-me um email se minha resposta for escolhida ou comentada',
		'a_notify_x_label' => 'Envia-me um email (^) se minha resposta for escolhida ou comentada',
		'a_waiting_your_approval' => 'Esta resposta aguarda a sua aprovação',
		'a_your_waiting_approval' => 'Esta resposta será avaliada e aprovada em breve.',
		'add_answer_button' => 'Publicar resposta',
		'add_comment_button' => 'Publicar comentário',
		'add_q_favorites' => 'Adicionar pergunta aos meus favoritos',
		'answer_button' => 'responder',
		'answer_limit' => 'Muitas respostas enviadas - tente novamente em uma hora',
		'answer_must_confirm' => '^5Confirme o seu email^6 para responder uma pergunta.',
		'answer_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para responder esta pergunta.',
		'answer_q_popup' => 'Responda esta pergunta',
		'approve_button' => 'aprovar',
		'ask_button' => 'Faça uma Pergunta',
		'ask_follow_from_a' => 'Sua pergunta será relacionada a essa resposta:',
		'ask_follow_title' => 'Fazer uma pergunta relacionada',
		'ask_limit' => 'Muitas perguntas enviadas - tente novamente em uma hora',
		'ask_must_confirm' => '^5Confirme o seu email^6 para fazer uma pergunta.',
		'ask_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para fazer uma pergunta.',
		'ask_same_q' => 'Antes de continuar, confira se a sua pergunta já foi feita:',
		'ask_title' => 'Faça um pergunta',
		'c_notify_email' => 'Envia-me um email nesse endereço se um comentário foi feito após o meu:',
		'c_notify_label' => 'Envia-me um email se um comentário for feito após o meu',
		'c_notify_x_label' => 'Envia-me um email (^) se um comentário for feito após o meu',
		'c_waiting_your_approval' => 'Este comentário aguarda a sua aprovação',
		'c_your_waiting_approval' => 'Este comentário será avaliado e aprovado em breve.',
		'category_js_note' => 'Para selecionar qualquer categoria, habilite o Javascript em seu navegador.',
		'category_required' => 'Escolha uma categoria',
		'claim_button' => 'Eu escrevi isso',
		'clear_flags_button' => 'remover denúncias',
		'clear_flags_popup' => 'Remover denúncias de todos os usuários',
		'close_button' => 'fechar',
		'close_duplicate_error' => 'A pergunta duplicada não foi encontrada - tente novamente escrevendo apenas o número da pergunta, como por exemplo, 123.',
		'close_duplicate' => 'Esta pergunta é duplicada de outra',
		'close_form_button' => 'Fechar pergunta',
		'close_form_title' => 'Fechar a pergunta',
		'close_original_note' => 'Também é possível colocar apenas o número da pergunta, como por exemplo, 123.',
		'close_original_title' => 'URL da pergunta original:',
		'close_q_popup' => 'Feche a pergunta para novas respostas',
		'close_reason_title' => 'Motivo para fechamento da pergunta:',
		'closed_as_duplicate' => 'fechada como duplicada de:',
		'closed_with_note' => 'fechada com o comentário:',
		'comment_a_popup' => 'Adicione um comentário na resposta',
		'comment_button' => 'comentar',
		'comment_limit' => 'Muitos comentários enviados - tente novamente em uma hora',
		'comment_must_confirm' => '^5Confirme o seu email^6 para comentar.',
		'comment_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para comentar.',
		'comment_on_a' => 'Na resposta: ',
		'comment_on_q' => 'Na pergunta: ',
		'comment_q_popup' => 'Comente a pergunta',
		'delete_a_popup' => 'Excluir a resposta permanentemente',
		'delete_button' => 'excluir',
		'delete_c_popup' => 'Excluir o comentário permanentemente',
		'delete_q_popup' => 'Excliur a pergunta permanentemente',
		'duplicate_content' => 'Sua publicação parece ser duplicada.',
		'edit_a_popup' => 'Edite a resposta',
		'edit_a_title' => 'Editar resposta',
		'edit_button' => 'editar',
		'edit_c_popup' => 'Edite o comentário',
		'edit_c_title' => 'Editar comentário',
		'edit_must_confirm' => '^5Confirme seu email^6 para editar.',
		'edit_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para editar.',
		'edit_q_popup' => 'Editar a pergunta',
		'edit_q_title' => 'Editar pergunta',
		'example_tags' => 'Exemplos de tags: ',
		'flag_a_popup' => 'Denunciar a resposta como spam ou inapropriado',
		'flag_button' => 'denunciar',
		'flag_c_popup' => 'Denunciar comentário como spam ou inapropriado',
		'flag_hide_button' => 'denunciar e ocultar',
		'flag_limit' => 'Muitas denúncias - tente novamente em uma hora',
		'flag_must_confirm' => '^5Confirme seu email^6 para denunciar.',
		'flag_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para denunciar.',
		'flag_not_allowed' => 'Isto não pode ser denunciado',
		'flag_q_popup' => 'Denunciar a pergunta como spam ou inapropriada',
		'follow_a_popup' => 'Fazer nova pergunta relacionada a esta resposta',
		'follow_button' => 'fazer pergunta relacionada',
		'follows_a' => 'relacionada a uma pergunta para:',
		'follows_q' => 'sobre a pergunta:',
		'hide_a_popup' => 'Ocultar a resposta',
		'hide_button' => 'ocultar',
		'hide_c_popup' => 'Ocultar o comentário',
		'hide_q_popup' => 'Ocultar a pergunta',
		'matching_tags' => 'Tags similares: ',
		'max_tags_x' => 'O máximo de ^ tags é permitido',
		'min_tags_x' => 'Forneça ao menos ^ tag/s',
		'notify_email_note' => 'Privacidade: Seu email será usado apenas para enviar estas notificações.',
		'q_category_label' => 'Categoria:',
		'q_content_label' => 'Mais informações sobre a pergunta:',
		'q_hidden_author' => 'Esta pergunta foi escondida pelo autor',
		'q_hidden_flagged' => 'Esta pergunta foi denunciada e oculta',
		'q_hidden_other' => 'Esta pergunta foi oculta',
		'q_notify_email' => 'Envia-me um email nesse endereço se minha pergunta for respondida ou comentada:',
		'q_notify_label' => 'Envia-me um email se minha pergunta for respondida ou comentada',
		'q_notify_x_label' => 'Envia-me um email (^) se minha pergunta for respondida ou comentada',
		'q_tags_comma_label' => 'Tags - use vírgula (,) para separar:',
		'q_tags_label' => 'Tags - use hífens para combinar palavras:',
		'q_title_label' => 'Sua pergunta em uma frase:',
		'q_waiting_approval' => 'Esta pergunta aguarda aprovação',
		'q_waiting_your_approval' => 'Esta pergunta aguarda a sua aprovação',
		'q_your_waiting_approval' => 'Sua pergunta será avaliada e aprovada em breve.',
		'recat_button' => 'recategorizar',
		'recat_popup' => 'Mudar a categoria da pergunta',
		'recat_q_title' => 'Recategorizar pergunta',
		'reject_button' => 'rejeitar',
		'remove_q_favorites' => 'Remover a pergunta dos meus favoritos',
		'reopen_button' => 'reabrir',
		'reply_button' => 'replicar',
		'reply_c_popup' => 'Replicar ao comentário',
		'reshow_button' => 'republicar',
		'retag_button' => 'reclassificar',
		'retag_cat_popup' => 'Mudar as categorias ou tags da pergunta',
		'retag_popup' => 'Mudar as tags da pergunta',
		'retag_q_title' => 'Reclassificar pergunta',
		'select_popup' => 'Clique para escolher como melhor resposta',
		'select_text' => 'Melhor resposta',
		'show_1_comment' => 'Mostrar 1 comentário',
		'show_1_previous_comment' => 'Mostrar um comentário anterior',
		'show_x_comments' => 'Mostrar ^ comentário',
		'show_x_previous_comments' => 'Mostrar ^ comentários anteriores',
		'unflag_button' => 'remover denúncia',
		'unflag_popup' => 'Remover a sua denúncia',
		'unselect_popup' => 'Clique para remover a escolha',
		'x_answers_title' => '^ Respostas',
		'your_answer_title' => 'Sua resposta',
		'your_comment_a' => 'Seu comentário nessa resposta:',
		'your_comment_q' => 'Seu comentário nessa pergunta:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.6-language-pt-BR.zip: pt/qa-lang-question.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-question.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for question page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer_title' => '1 Resposta',
		'a_convert_to_c_on' => 'Converter esta resposta em comentário em:',
		'a_convert_to_c' => 'Converter esta resposta em um comentário',
		'a_convert_warn_cs' => 'Aviso: Esta conversão não pode ser revertida e também moverá os comentários dessa resposta.',
		'a_convert_warn' => 'Aviso: Esta conversão não pode ser revertida.',
		'a_notify_email' => 'Envia-me um email nesse endereço se minha resposta for escolhida ou comentada:',
		'a_notify_label' => 'Envia-me um email se minha resposta for escolhida ou comentada',
		'a_notify_x_label' => 'Envia-me um email (^) se minha resposta for escolhida ou comentada',
		'a_waiting_your_approval' => 'Esta resposta aguarda a sua aprovação',
		'a_your_waiting_approval' => 'Esta resposta será avaliada e aprovada em breve.',
		'add_answer_button' => 'Publicar resposta',
		'add_comment_button' => 'Publicar comentário',
		'add_q_favorites' => 'Adicionar pergunta aos meus favoritos',
		'anon_name_label' => 'Seu nome (opcional):',
		'answer_button' => 'responder',
		'answer_limit' => 'Muitas respostas enviadas - tente novamente em uma hora',
		'answer_must_be_approved' => 'Somente usuários aprovados podem responder perguntas.',
		'answer_must_confirm' => '^5Confirme o seu email^6 para responder uma pergunta.',
		'answer_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para responder esta pergunta.',
		'answer_q_popup' => 'Responda esta pergunta',
		'approve_button' => 'aprovar',
		'ask_button' => 'Faça uma Pergunta',
		'ask_follow_from_a' => 'Sua pergunta será relacionada a essa resposta:',
		'ask_follow_title' => 'Fazer uma pergunta relacionada',
		'ask_limit' => 'Muitas perguntas enviadas - tente novamente em uma hora',
		'ask_must_be_approved' => 'Somente usuários aprovados podem fazer perguntas.',
		'ask_must_confirm' => '^5Confirme o seu email^6 para fazer uma pergunta.',
		'ask_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para fazer uma pergunta.',
		'ask_same_q' => 'Antes de continuar, confira se a sua pergunta já foi feita:',
		'ask_title' => 'Faça um pergunta',
		'c_notify_email' => 'Envia-me um email nesse endereço se um comentário foi feito após o meu:',
		'c_notify_label' => 'Envia-me um email se um comentário for feito após o meu',
		'c_notify_x_label' => 'Envia-me um email (^) se um comentário for feito após o meu',
		'c_waiting_your_approval' => 'Este comentário aguarda a sua aprovação',
		'c_your_waiting_approval' => 'Este comentário será avaliado e aprovado em breve.',
		'category_js_note' => 'Para selecionar qualquer categoria, habilite o Javascript em seu navegador.',
		'category_required' => 'Escolha uma categoria',
		'category_ask_not_allowed' => 'Você não tem permissão para fazer perguntas nesta categoria',
		'claim_button' => 'Eu escrevi isso',
		'clear_flags_button' => 'remover denúncias',
		'clear_flags_popup' => 'Remover denúncias de todos os usuários',
		'close_button' => 'fechar',
		'close_duplicate_error' => 'A pergunta duplicada não foi encontrada - tente novamente escrevendo apenas o número da pergunta, como por exemplo, 123.',
		'close_duplicate' => 'Esta pergunta é duplicada de outra',
		'close_form_button' => 'Fechar pergunta',
		'close_form_title' => 'Fechar a pergunta',
		'close_original_note' => 'Também é possível colocar apenas o número da pergunta, como por exemplo, 123.',
		'close_original_title' => 'URL da pergunta original:',
		'close_q_popup' => 'Feche a pergunta para novas respostas',
		'close_reason_title' => 'Motivo para fechamento da pergunta:',
		'closed_as_duplicate' => 'fechada como duplicada de:',
		'closed_with_note' => 'fechada com o comentário:',
		'comment_a_popup' => 'Adicione um comentário na resposta',
		'comment_button' => 'comentar',
		'comment_limit' => 'Muitos comentários enviados - tente novamente em uma hora',
		'comment_must_be_approved' => 'Somente usuários aprovados podem comentar.',
		'comment_must_confirm' => '^5Confirme o seu email^6 para comentar.',
		'comment_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para comentar.',
		'comment_on_a' => 'Na resposta: ',
		'comment_on_q' => 'Na pergunta: ',
		'comment_q_popup' => 'Comente a pergunta',
		'delete_a_popup' => 'Excluir a resposta permanentemente',
		'delete_button' => 'excluir',
		'delete_c_popup' => 'Excluir o comentário permanentemente',
		'delete_q_popup' => 'Excliur a pergunta permanentemente',
		'duplicate_content' => 'Sua publicação parece ser duplicada.',
		'edit_a_popup' => 'Edite a resposta',
		'edit_a_title' => 'Editar resposta',
		'edit_button' => 'editar',
		'edit_c_popup' => 'Edite o comentário',
		'edit_c_title' => 'Editar comentário',
		'edit_must_confirm' => '^5Confirme seu email^6 para editar.',
		'edit_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para editar.',
		'edit_q_popup' => 'Editar a pergunta',
		'edit_q_title' => 'Editar pergunta',
		'example_tags' => 'Exemplos de tags: ',
		'flag_a_popup' => 'Denunciar a resposta como spam ou inapropriado',
		'flag_button' => 'denunciar',
		'flag_c_popup' => 'Denunciar comentário como spam ou inapropriado',
		'flag_hide_button' => 'denunciar e ocultar',
		'flag_limit' => 'Muitas denúncias - tente novamente em uma hora',
		'flag_must_confirm' => '^5Confirme seu email^6 para denunciar.',
		'flag_must_login' => '^1Entre^2 ou ^3cadastre-se^4 para denunciar.',
		'flag_not_allowed' => 'Isto não pode ser denunciado',
		'flag_q_popup' => 'Denunciar a pergunta como spam ou inapropriada',
		'follow_a_popup' => 'Fazer nova pergunta relacionada a esta resposta',
		'follow_button' => 'fazer pergunta relacionada',
		'follows_a' => 'relacionada a uma pergunta para:',
		'follows_q' => 'sobre a pergunta:',
		'hide_a_popup' => 'Ocultar a resposta',
		'hide_button' => 'ocultar',
		'hide_c_popup' => 'Ocultar o comentário',
		'hide_q_popup' => 'Ocultar a pergunta',
		'matching_tags' => 'Tags similares: ',
		'max_tags_x' => 'O máximo de ^ tags é permitido',
		'min_tags_x' => 'Forneça ao menos ^ tag/s',
		'notify_email_note' => 'Privacidade: Seu email será usado apenas para enviar estas notificações.',
		'q_category_label' => 'Categoria:',
		'q_content_label' => 'Mais informações sobre a pergunta:',
		'q_hidden_author' => 'Esta pergunta foi escondida pelo autor',
		'q_hidden_flagged' => 'Esta pergunta foi denunciada e oculta',
		'q_hidden_other' => 'Esta pergunta foi oculta',
		'q_notify_email' => 'Envia-me um email nesse endereço se minha pergunta for respondida ou comentada:',
		'q_notify_label' => 'Envia-me um email se minha pergunta for respondida ou comentada',
		'q_notify_x_label' => 'Envia-me um email (^) se minha pergunta for respondida ou comentada',
		'q_tags_comma_label' => 'Tags - use vírgula (,) para separar:',
		'q_tags_label' => 'Tags - use hífens para combinar palavras:',
		'q_title_label' => 'Sua pergunta em uma frase:',
		'q_waiting_approval' => 'Esta pergunta aguarda aprovação',
		'q_waiting_your_approval' => 'Esta pergunta aguarda a sua aprovação',
		'q_your_waiting_approval' => 'Sua pergunta será avaliada e aprovada em breve.',
		'recat_button' => 'recategorizar',
		'recat_popup' => 'Mudar a categoria da pergunta',
		'recat_q_title' => 'Recategorizar pergunta',
		'reject_button' => 'rejeitar',
		'remove_q_favorites' => 'Remover a pergunta dos meus favoritos',
		'reopen_button' => 'reabrir',
		'reply_button' => 'replicar',
		'reply_c_popup' => 'Replicar ao comentário',
		'reshow_button' => 'republicar',
		'retag_button' => 'reclassificar',
		'retag_cat_popup' => 'Mudar as categorias ou tags da pergunta',
		'retag_popup' => 'Mudar as tags da pergunta',
		'retag_q_title' => 'Reclassificar pergunta',
		'save_silent_label' => 'Salvar secretamente para não mostrar que isto foi editado', 
		'select_popup' => 'Clique para escolher como melhor resposta',
		'select_text' => 'Melhor resposta',
		'show_1_comment' => 'Mostrar 1 comentário',
		'show_1_previous_comment' => 'Mostrar um comentário anterior',
		'show_x_comments' => 'Mostrar ^ comentário',
		'show_x_previous_comments' => 'Mostrar ^ comentários anteriores',
		'unflag_button' => 'remover denúncia',
		'unflag_popup' => 'Remover a sua denúncia',
		'unselect_popup' => 'Clique para remover a escolha',
		'x_answers_title' => '^ Respostas',
		'your_answer_title' => 'Sua resposta',
		'your_comment_a' => 'Seu comentário nessa resposta:',
		'your_comment_q' => 'Seu comentário nessa pergunta:',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
